==> tweego_0.6.0.tar.gz: tweego-0.6.0/src/backend.h <==
/*
 *
 *  Copyright (c) 2010 Zagaia (INdT - Instituto Nokia de Tecnologia/
 *       FUCAPI - Fundação Centro de Análise, Pesquisa e Inovação Tecnológica)
 *
 *  This file is part of TweeGo.
 *
 *  TweeGo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TweeGo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with TweeGo. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef BACKEND_H
#define BACKEND_H

#include <QtNetwork>

#include "twitterapi/twitterapi.h"

/*! \namespace Timeline Contains different types of timeline to load.
  */
namespace Timeline
{
    enum TimelineType { Users, Friends, Public, Mentions };
}

/*!
 * \class Backend
 * \brief Handles all operations between the application and the twitlib.
 */
class Backend : public QObject
{
    Q_OBJECT

    public:
        static Backend *getInstance(void);
        void resetTimelinePage(Timeline::TimelineType type);
        void setConsumerKey(const QByteArray &consumerKey);
        void setConsumerSecret(const QByteArray &consumerSecret);
        void setLogin(const QString &login);
        void setPassword(const QString &password);
        void verifyCredentials(void);
        UserInfo userInfo(void);
        EntryList homeTweets(void);
        EntryList mentionsTweets(void);
        void abort(void);
        void update(QString status, QString lat="", QString lon="", quint64 inReplyToStatusId=0);
        void addFavorite(quint64 id);
        void removeFavorite(quint64 id);
        void removeStatus(quint64 id);
        void removeFriendship(quint64 id);
        void addFriendship(quint64 id);
        void sendDirectMessage(QString user, QString msg);
        bool updateProfileImage(QString image);

    private:
        Backend(void);
        void _addNewHomeTweets(EntryList);
        void _addNewMentionsTweets(EntryList);

    public slots:
        void getTimeline(Timeline::TimelineType type);

    private slots:
        void _parseEntries(EntryList entries);
        void _credentials(EntryList entries);
        void _error(QNetworkReply::NetworkError);
        void _deleteEntry(quint64 id);

    signals:
        void signedOn(void);
        void connectionError(QString);
        void updateError(QString);
        void updatePosted(void);
        void gotFriendsTimeline(void);
        void gotMentions(void);
        void deletedTweet(quint64);

    private:
        QMap<quint64, Entry> _homeTweetsMap;
        EntryList _homeTweets;

        QMap<quint64, Entry> _mentionsTweetsMap;
        EntryList _mentionsTweets;

        static Backend *_instance;
        UserInfo userInformations;
        TwitterAPI *twitterapi;
        QList<int> conns;
        int mentionsPage;
        int friendsPage;
        int userPage;
};

#endif // BACKEND_H

==> tweego_0.6.5-4.tar.gz: tweego-0.6.5/src/backend.h <==
/*
 *
 *  Copyright (c) 2010 Zagaia (INdT - Instituto Nokia de Tecnologia/
 *       FUCAPI - Fundação Centro de Análise, Pesquisa e Inovação Tecnológica)
 *
 *  This file is part of TweeGo.
 *
 *  TweeGo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TweeGo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with TweeGo. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef BACKEND_H
#define BACKEND_H

#include <QtNetwork>

#include "twitterapi/twitterapi.h"

/*! \namespace Timeline Contains different types of timeline to load.
  */
namespace Timeline
{
    enum TimelineType { Users, Friends, Public, Mentions };
}

/*!
 * \class Backend
 * \brief Handles all operations between the application and the twitlib.
 */
class Backend : public QObject
{
    Q_OBJECT

    public:
        static Backend *getInstance(void);
        void resetTimelinePage(Timeline::TimelineType type);
        void setConsumerKey(const QByteArray &consumerKey);
        void setConsumerSecret(const QByteArray &consumerSecret);
        void setLogin(const QString &login);
        void setPassword(const QString &password);
        void verifyCredentials(void);
        UserInfo userInfo(void);
        EntryList getHomeTweets(void);
        EntryList getMentionsTweets(void);
        Entry getUpdateTweet(void);
        void abort(void);
        void update(QString status, QString lat="", QString lon="", quint64 inReplyToStatusId=0);
        void addFavorite(quint64 id);
        void removeFavorite(quint64 id);
        void removeStatus(quint64 id);
        void removeFriendship(quint64 id);
        void addFriendship(quint64 id);
        void sendDirectMessage(QString user, QString msg);
        bool updateProfileImage(QString image);


    private:
        Backend(void);
        void _addNewHomeTweets(EntryList);
        void _addNewMentionsTweets(EntryList);

    public slots:
        void getTimeline(Timeline::TimelineType type);

    private slots:
        void _parseEntries(EntryList entries);
        void _credentials(EntryList entries);
        void _error(QNetworkReply::NetworkError);
        void _deleteEntry(quint64 id);

    signals:
        void signedOn(void);
        void connectionError(QString);
        void updateError(QString);
        void updatePosted(void);
        void gotFriendsTimeline(void);
        void gotMentions(void);
        void deletedTweet(quint64);

    private:
        QMap<quint64, Entry> _homeTweetsMap;
        EntryList _homeTweets;

        QMap<quint64, Entry> _mentionsTweetsMap;
        EntryList _mentionsTweets;

        Entry _updateTweet;
        static Backend *_instance;
        UserInfo _userInformations;
        TwitterAPI *_twitterapi;
        QList<int> _conns;
        int _mentionsPage;
        int _friendsPage;
        int _userPage;
};

#endif // BACKEND_H
